DataModel

Struct DataModel 

pub struct DataModel {
    pub name: Option<String>,
    pub objects: Vec<Object>,
    pub enums: Vec<Enumeration>,
    pub config: Option<FrontMatter>,
}

Fields

name: Option<String>objects: Vec<Object>enums: Vec<Enumeration>config: Option<FrontMatter>

Implementations

Source

impl DataModel

pub fn new(name: Option<String>, config: Option<FrontMatter>) -> Self

pub fn validate_json( &self, path: &Path, root: Option<String>, ) -> Result<Vec<ValidationError>, Box<dyn Error>>

Validates a dataset against the data model.

This function takes the path to a dataset and validates it against the current data model. It returns a vector of validation errors if any validation issues are found, or an empty vector if the validation is successful.

Arguments
  • path - A reference to the path of the dataset to validate.
  • root - An optional root path for the schema. Will use the first object if not provided.
Returns

A Result containing a vector of ValidationError if validation fails, or an empty vector if successful.

pub fn json_schema( &self, obj_name: Option<String>, openai: bool, ) -> Result<String, Box<dyn Error>>

pub fn json_schema_all( &self, path: PathBuf, openai: bool, ) -> Result<(), Box<dyn Error>>

pub fn json_ld_header( &self, root: Option<&str>, ) -> Result<JsonLdHeader, Box<dyn Error>>

Generates a JSON-LD header (JsonLdHeader) for the data model, suitable for use in JSON-LD serialization.

This method constructs a JsonLdHeader using the model’s configuration and optionally a specified root object. The header contains the appropriate JSON-LD @context, @id, and @type for the model or selected object.

Arguments
  • root - Optional. The name of the root object to use. If None, the first object in the model is used.
Returns
  • Ok(JsonLdHeader) with the generated JSON-LD header if successful.
  • Err(Box<dyn Error>) if the generation fails (for example, if the root is not found).
pub fn internal_schema(&self) -> String

pub fn from_internal_schema(path: &Path) -> Result<Self, Box<dyn Error>>

pub fn sort_attrs(&mut self)

Sort the attributes of all objects by required

pub fn convert_to( &mut self, template: &Templates, config: Option<&HashMap<String, String>>, ) -> Result<String, Error>

pub fn merge(&mut self, other: &Self)

pub fn from_markdown(path: &Path) -> Result<Self, Validator>

Parse a markdown file and create a data model

  • path - Path to the markdown file
Examples
use std::path::Path;
use mdmodels_core::datamodel::DataModel;

let path = Path::new("tests/data/model.md");
let model = DataModel::from_markdown(path);
Returns

A data model

pub fn from_markdown_string(content: &str) -> Result<Self, Validator>

Parse a markdown file and create a data model

  • path - Path to the markdown file
Examples
use std::path::Path;
use std::fs;
use mdmodels_core::datamodel::DataModel;

let path = Path::new("tests/data/model.md");
let content = fs::read_to_string(path).unwrap();
let model = DataModel::from_markdown_string(content.as_str());
Returns

A data model

pub fn from_json_schema(path: &Path) -> Result<Self, DataModelError>

Parse a JSON schema file and create a data model

  • path - Path to the JSON schema file
Returns

A data model

pub fn from_json_schema_string(content: &str) -> Result<Self, DataModelError>

Parse a JSON schema string and create a data model

  • content - The JSON schema string
Returns

A data model

pub fn from_json_schema_object( schema: SchemaObject, ) -> Result<Self, DataModelError>

Parse a JSON schema object and create a data model

  • schema - The JSON schema object
Returns

A data model