Represents the JSON-LD document header, containing context, id, and type definitions.
This structure is used as the envelope for JSON-LD documents and nodes.
Provides a full mapping for a term in a JSON-LD context, supporting advanced features such as:
type coercion, container types, nested context definition, language, protection, prefixing, reverse properties, and data nesting.