pub struct Validator {
pub is_valid: bool,
pub errors: Vec<ValidationError>,
pub object_positions: HashMap<String, Vec<Position>>,
pub enum_positions: HashMap<String, Vec<Position>>,
}Expand description
Validator for checking the integrity of a data model.
Fields
is_valid: boolerrors: Vec<ValidationError>object_positions: HashMap<String, Vec<Position>>enum_positions: HashMap<String, Vec<Position>>Implementations
Sourceimpl Validator
impl Validator
pub fn reset(&mut self)
Sourcepub fn add_error(&mut self, error: ValidationError)
pub fn add_error(&mut self, error: ValidationError)
Sourcepub fn log_result(&self)
pub fn log_result(&self)
Prints all validation errors to the log.
This method iterates over the errors vector and logs each error using the error! macro.