pub struct Attribute {Show 13 fields
pub name: String,
pub is_array: bool,
pub is_id: bool,
pub dtypes: Vec<String>,
pub docstring: String,
pub options: Vec<AttrOption>,
pub term: Option<String>,
pub required: bool,
pub default: Option<DataType>,
pub xml: Option<XMLType>,
pub is_enum: bool,
pub position: Option<Position>,
pub import_prefix: Option<String>,
}Expand description
Represents an attribute with various properties and options.
Fields
name: StringThe name of the attribute.
is_array: boolIndicates if the attribute is an array.
is_id: boolIs an identifier or not
dtypes: Vec<String>Data types associated with the attribute.
docstring: StringDocumentation string for the attribute.
options: Vec<AttrOption>List of additional options for the attribute.
term: Option<String>Term associated with the attribute, if any.
required: boolIndicates if the attribute is required.
default: Option<DataType>Default value for the attribute.
xml: Option<XMLType>XML type information for the attribute.
is_enum: boolIs an enumeration or not
position: Option<Position>The line number of the attribute
import_prefix: Option<String>The prefix of the attribute, if it is an import
Implementations
Sourceimpl Attribute
impl Attribute
Sourcepub fn new(name: String, required: bool) -> Self
pub fn new(name: String, required: bool) -> Self
Creates a new Attribute with the given name and required status.
Arguments
name- The name of the attribute.required- Indicates if the attribute is required.
Sourcepub fn set_docstring(&mut self, docstring: String)
pub fn set_docstring(&mut self, docstring: String)
Sets the documentation string for the attribute.
Arguments
docstring- The documentation string to set.
Sourcepub fn set_position(&mut self, position: Position)
pub fn set_position(&mut self, position: Position)
Sourcepub fn to_json_schema(&self) -> String
pub fn to_json_schema(&self) -> String